%define major            1
%define libname          %mklibname audit %{major}
%define develname        %mklibname audit -d

%define auparsemajor     0
%define auparselibname   %mklibname auparse %{auparsemajor}
%define auparsedevelname %mklibname auparse -d

Summary:        User-space tools for Linux kernel auditing
Name:           audit
Version:        4.0.3
Release:        %mkrel 1
License:        LGPLv2+
Group:          System/Base
# https://people.redhat.com/sgrubb/audit/
URL:            https://github.com/linux-audit/audit-userspace
Source0:        https://github.com/linux-audit/audit-userspace/archive/v%{version}/audit-userspace-%{version}.tar.gz
BuildRequires:  gettext-devel
BuildRequires:  glibc-devel >= 2.6
BuildRequires:  intltool
BuildRequires:  kernel-headers >= 5.0
BuildRequires:  krb5-devel
BuildRequires:  pkgconfig(libcap-ng)
BuildRequires:  pkgconfig(liburing)
BuildRequires:  libtool
BuildRequires:  openldap-devel
BuildRequires:  pkgconfig(python3)
BuildRequires:  swig
BuildRequires:  tcp_wrappers-devel
# for macro definition:
BuildRequires:  pkgconfig(libsystemd)
Requires(preun): rpm-helper
Requires(post): rpm-helper
Requires(postun):rpm-helper
Requires:       tcp_wrappers
Requires:       %{name}-rules%{?_isa} = %{version}-%{release}

%description
The audit package contains the user space utilities for storing and searching
the audit records generate by the audit subsystem in the Linux kernel.

%package -n     %{libname}
Summary:        Main libraries for %{name}
Group:          System/Libraries

%description -n %{libname}
This package contains the main libraries for %{name}.

%package -n     %{develname}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       libaudit-devel = %{version}-%{release}
Provides:       audit-devel = %{version}-%{release}
Provides:       audit-libs-devel = %{version}-%{release}

%description -n %{develname}
This package contains development files for %{name}.

%package -n     %{auparselibname}
Summary:        Main libraries for %{name}
Group:          System/Libraries

%description -n %{auparselibname}
This package contains the main auparse libraries for %{name}.

%package -n     %{auparsedevelname}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{auparselibname} = %{version}-%{release}
Provides:       auparse-devel = %{version}-%{release}


%description -n %{auparsedevelname}
This package contains development files for %{name}.

%package -n     python3-audit
Summary:        Python3 bindings for libaudit
License:        LGPLv2+
Group:          Development/Python
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n python3-audit
The python3-audit package contains the bindings so that libaudit
and libauparse can be used by python3.

%package -n     audispd-plugins
Summary:        Plugins for the audit event dispatcher
Group:          System/Base
Requires:       %{name} = %{version}

Conflicts:      audit < 3.1.2-6

%description -n audispd-plugins
The audispd-plugins package provides plugins for the real-time interface to the
audit system, audispd. These plugins can do things like relay events to remote
machines.

%package -n	audispd-plugins-zos
Summary:	z/OS plugin for the audit event dispatcher
Group:		System/Base
Requires:	%{name} = %{version}
Requires:	openldap

%description -n audispd-plugins-zos
The audispd-plugins-zos package provides a plugin that will forward all
incoming audit events, as they happen, to a configured z/OS SMF (Service
Management Facility) database, through an IBM Tivoli Directory Server
(ITDS) set for Remote Audit service.

%package rules
Summary:	audit rules and utilities
Group:		System/Base
License:	GPL-2.0-or-later
Recommends:	%{name} >= %{version}-%{release}

Conflicts:	audit < 3.1.2-6

%description rules
The audit rules package contains the rules and utilities to load audit rules.

%prep
%autosetup -n audit-userspace-%{version}

find -type d -name ".libs" | xargs rm -rf

# fix runstatedir
sed -i -e 's,/var/run,%{_rundir},g' $(grep -rl /var/run)

%build
./autogen.sh
# Remove the ids code, its not ready
sed -i 's/ ids / /' audisp/plugins/Makefile.am
sed -i 's/ ids / /' audisp/plugins/Makefile.in
%configure \
    --disable-static \
    --with-libwrap \
    --enable-gssapi-krb5=yes \
    --with-libcap-ng=yes \
    --with-arm --with-aarch64 --with-riscv \
    --without-golang \
    --enable-zos-remote \
    --enable-experimental \
    --with-io_uring

%make_build

%install
%{__install} -d %{buildroot}%{_sysconfdir}/%{name}/rules.d
%{__install} -d %{buildroot}%{_var}/log/audit
%{__install} -d %{buildroot}%{_libdir}/audit
%{__install} -d %{buildroot}%{_var}/spool/audit

%make_install

%post
%_tmpfilescreate %{name}

## This hack is because the auditd.service needs to be started before sysinit.target. So let's just enable and start
## the service manually after installation. This needs to be revisited after our %%_post_service has been adjusted
systemctl enable -q auditd.service
systemctl start -q auditd.service
# %%_post_service auditd.service

%preun
## For some unknow reason "systemctl stop" doesn't work so use "systemctl kill" instead:
## Failed to stop auditd.service: Operation refused, unit auditd.service may be requested
## by dependency only.
systemctl kill -q auditd.service
systemctl disable -q auditd.service

%post rules
# Copy default rules into place on new installation
files=`ls /etc/audit/rules.d/ 2>/dev/null | wc -w`
if [ "$files" -eq 0 ] ; then
# FESCO asked for audit to be off by default. #1117953
	if [ -e %{_datadir}/%{name}/rules/10-no-audit.rules ] ; then
	        cp %{_datadir}/audit/rules/10-no-audit.rules /etc/audit/rules.d/audit.rules
	else
		touch /etc/audit/rules.d/audit.rules
	fi
	chmod 0600 /etc/audit/rules.d/audit.rules
fi

%preun rules
%systemd_preun audit-rules.service
# If uninstalling, delete the rules loaded in the kernel
if [ $1 -eq 0 ] ; then
    auditctl -D > /dev/null 2>&1 || true
fi


%files
%doc README.md ChangeLog init.d/auditd.cron
%license COPYING
%attr(0644,root,root) %{_mandir}/man8/auditd.8*
%attr(0644,root,root) %{_mandir}/man8/aulast.8*
%attr(0644,root,root) %{_mandir}/man8/aulastlog.8*
%attr(0644,root,root) %{_mandir}/man8/aureport.8*
%attr(0644,root,root) %{_mandir}/man8/ausearch.8*
%attr(0644,root,root) %{_mandir}/man8/ausyscall.8*
%attr(0644,root,root) %{_mandir}/man5/auditd.conf.5*
%attr(0644,root,root) %{_mandir}/man5/ausearch-expression.5*
%attr(0644,root,root) %{_mandir}/man5/auditd-plugins.5*
%attr(0755,root,root) %{_sbindir}/auditd
%attr(0755,root,root) %{_sbindir}/aureport
%attr(0755,root,root) %{_sbindir}/ausearch
%attr(0755,root,root) %{_bindir}/aulast
%attr(0755,root,root) %{_bindir}/aulastlog
%attr(0755,root,root) %{_bindir}/ausyscall
%attr(644,root,root) %{_unitdir}/auditd.service
%attr(640,root,root) %{_tmpfilesdir}/%{name}.conf
%attr(750,root,root) %dir %{_libexecdir}/initscripts/legacy-actions/auditd
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/resume
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/rotate
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/state
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/stop
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/restart
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/condrestart
%attr(750,root,root) %{_libexecdir}/initscripts/legacy-actions/auditd/reload
%attr(0700,root,root) %dir %{_var}/log/audit
%attr(0750,root,root) %dir %{_sysconfdir}/audit/plugins.d
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/auditd.conf

%files -n %{libname}
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/libaudit.conf
%{_libdir}/libaudit.so.%{major}{,.*}
%attr(0644,root,root) %{_mandir}/man5/libaudit.conf.5*

%files -n %{develname}
%doc ChangeLog contrib/plugin
%{_libdir}/libaudit.so
%{_includedir}/libaudit.h
%{_includedir}/audit_logging.h
%{_includedir}/audit-records.h
%{_datadir}/aclocal/audit.m4
%{_libdir}/pkgconfig/audit.pc
%{_mandir}/man3/audit_*
%{_mandir}/man3/ausearch_*
%{_mandir}/man3/get_auditfail_action.3*
%{_mandir}/man3/set_aumessage_mode.3*

%files -n %{auparselibname}
%{_libdir}/libauparse.so.%{auparsemajor}{,.*}

%files -n %{auparsedevelname}
%doc contrib/plugin
%{_libdir}/libauparse.so
%{_includedir}/auparse-defs.h
%{_includedir}/auparse.h
%{_libdir}/pkgconfig/auparse.pc
%{_mandir}/man3/auparse_*

%files -n python3-audit
%{python3_sitearch}/*

%files rules
%doc rules
%attr(0755,root,root) %dir %{_datadir}/%{name}-rules
%attr(0644,root,root) %{_datadir}/%{name}-rules/*
%attr(0644,root,root) %{_mandir}/man8/auditctl.8*
%attr(0644,root,root) %{_mandir}/man8/augenrules.8*
%attr(0644,root,root) %{_mandir}/man7/audit.rules.7*
%attr(0755,root,root) %{_sbindir}/auditctl
%attr(0755,root,root) %{_sbindir}/augenrules
%attr(0644,root,root) %{_unitdir}/audit-rules.service
%attr(0750,root,root) %dir %{_sysconfdir}/audit
%attr(0750,root,root) %dir %{_sysconfdir}/audit/rules.d
%ghost %config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/rules.d/audit.rules
%ghost %config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/audit.rules
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/audit-stop.rules

%files -n audispd-plugins
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/audisp-remote.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/plugins.d/au-remote.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/plugins.d/syslog.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/audisp-statsd.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/plugins.d/au-statsd.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/plugins.d/af_unix.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/audisp-filter.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/plugins.d/filter.conf
%attr(0755,root,root) %{_sbindir}/audisp-af_unix
%attr(0750,root,root) %{_sbindir}/audisp-remote
%attr(0750,root,root) %{_sbindir}/audisp-syslog
%attr(0750,root,root) %{_sbindir}/audisp-statsd
%attr(0750,root,root) %{_sbindir}/audisp-filter
%attr(0750,root,root) %dir %{_var}/spool/audit
%attr(0644,root,root) %{_mandir}/man5/audisp-remote.conf.5*
%attr(0644,root,root) %{_mandir}/man8/audisp-af_unix.8*
%attr(0644,root,root) %{_mandir}/man8/audisp-remote.8*
%attr(0644,root,root) %{_mandir}/man8/audisp-syslog.8*
%attr(0644,root,root) %{_mandir}/man8/audisp-statsd.8*
%attr(0644,root,root) %{_mandir}/man8/audisp-filter.8*

%files -n audispd-plugins-zos
%attr(0644,root,root) %{_mandir}/man8/audispd-zos-remote.8*
%attr(0644,root,root) %{_mandir}/man5/zos-remote.conf.5*
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/plugins.d/audispd-zos-remote.conf
%config(noreplace) %attr(0640,root,root) %{_sysconfdir}/audit/zos-remote.conf
%attr(0750,root,root) %{_sbindir}/audispd-zos-remote


%changelog
* Wed Jan 08 2025 daviddavid <daviddavid> 4.0.3-1.mga10
+ Revision: 2136245
- new version: 4.0.3

* Mon Dec 02 2024 daviddavid <daviddavid> 4.0.2-1.mga10
+ Revision: 2120698
- new version: 4.0.2
- create and move all rules files to a new -rules sub-pkg

* Fri Apr 05 2024 wally <wally> 3.1.2-5.mga10
+ Revision: 2054585
- basesystem rebuild for i686

* Mon Dec 25 2023 wally <wally> 3.1.2-4.mga10
+ Revision: 2021317
- one more rebuild for py3.12 due to a vanished pkgs

* Thu Dec 21 2023 papoteur <papoteur> 3.1.2-3.mga10
+ Revision: 2020795
- rebuild for python 3.12

* Sat Dec 09 2023 papoteur <papoteur> 3.1.2-2.mga10
+ Revision: 2016039
- rebuild for python 3.12

* Sat Sep 16 2023 daviddavid <daviddavid> 3.1.2-1.mga10
+ Revision: 1987070
- new version: 3.1.2
- remove flex-array-workaround hack

* Thu May 18 2023 daviddavid <daviddavid> 3.1.1-1.mga9
+ Revision: 1957186
- new version: 3.1.1
- add back patches from fedora to fix build
+ luigiwalser <luigiwalser>
- 3.1
- enable io_uring support
- remove patches

* Sat Nov 12 2022 daviddavid <daviddavid> 3.0.9-2.mga9
+ Revision: 1906496
- really undo the workaround with patch2 in install stage

* Wed Nov 09 2022 ghibo <ghibo> 3.0.9-1.mga9
+ Revision: 1904976
- Fix building.
- Merge Patch1 and Patch2 from FC.
+ luigiwalser <luigiwalser>
- 3.0.9

* Thu Mar 31 2022 luigiwalser <luigiwalser> 3.0.8-1.mga9
+ Revision: 1837593
- 3.0.8

* Thu Mar 24 2022 umeabot <umeabot> 3.0.7-3.mga9
+ Revision: 1824145
- Mageia 9 Mass Rebuild

* Sat Feb 12 2022 neoclust <neoclust> 3.0.7-2.mga9
+ Revision: 1773306
- rebuild for python 3.10

* Tue Jan 25 2022 luigiwalser <luigiwalser> 3.0.7-1.mga9
+ Revision: 1769793
- 3.0.7

* Mon Oct 04 2021 luigiwalser <luigiwalser> 3.0.6-1.mga9
+ Revision: 1749424
- 3.0.6

* Thu Aug 12 2021 luigiwalser <luigiwalser> 3.0.5-1.mga9
+ Revision: 1741140
- 3.0.5

* Mon Aug 02 2021 luigiwalser <luigiwalser> 3.0.3-1.mga9
+ Revision: 1738634
- 3.0.3

* Sat Jun 12 2021 joequant <joequant> 3.0.2-1.mga9
+ Revision: 1730505
- update to 3.0.2

* Sat Mar 20 2021 neoclust <neoclust> 3.0.1-2.mga9
+ Revision: 1705985
- Rebuild against python 3.9

* Tue Mar 02 2021 daviddavid <daviddavid> 3.0.1-1.mga9
+ Revision: 1695942
- new version: 3.0.1
+ luigiwalser <luigiwalser>
- remove old references to kernel 2.6

* Sun Dec 20 2020 luigiwalser <luigiwalser> 3.0-1.mga8
+ Revision: 1661868
- 3.0
- enable krb5

* Sat Oct 24 2020 wally <wally> 2.8.5-4.mga8
+ Revision: 1639091
- build with -fcommon

* Sun Feb 16 2020 umeabot <umeabot> 2.8.5-3.mga8
+ Revision: 1531653
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Sep 14 2019 daviddavid <daviddavid> 2.8.5-2.mga8
+ Revision: 1440739
- rebuild for python3.8
- drop python2 support

* Wed Mar 20 2019 luigiwalser <luigiwalser> 2.8.5-1.mga7
+ Revision: 1379165
- 2.8.5

* Sun Feb 24 2019 daviddavid <daviddavid> 2.8.4-5.mga7
+ Revision: 1369829
- rebuild for new libprelude 5.0.0
- rename python-audit to python2-audit

* Sat Feb 16 2019 wally <wally> 2.8.4-4.mga7
+ Revision: 1367516
- use /run as runstatedir instead of /var/run

* Mon Jan 07 2019 shlomif <shlomif> 2.8.4-3.mga7
+ Revision: 1350854
- Rebuild for python3 3.7

* Fri Sep 21 2018 umeabot <umeabot> 2.8.4-2.mga7
+ Revision: 1295124
- Mageia 7 Mass Rebuild

* Sun Jun 24 2018 luigiwalser <luigiwalser> 2.8.4-1.mga7
+ Revision: 1239562
- 2.8.4

* Mon Apr 16 2018 kekepower <kekepower> 2.8.3-1.mga7
+ Revision: 1219263
- Update to version 2.8.3

* Wed Dec 20 2017 luigiwalser <luigiwalser> 2.8.2-1.mga7
+ Revision: 1183523
- 2.8.2

* Fri Dec 08 2017 shlomif <shlomif> 2.8.1-1.mga7
+ Revision: 1181690
- New version 2.8.1

* Fri Sep 22 2017 luigiwalser <luigiwalser> 2.7.8-1.mga7
+ Revision: 1157263
- 2.7.8

* Sat Aug 05 2017 pterjan <pterjan> 2.7.7-2.mga7
+ Revision: 1135186
- Rebuild for python 3.6

* Wed Jun 21 2017 luigiwalser <luigiwalser> 2.7.7-1.mga6
+ Revision: 1108112
- 2.7.7

* Sun May 21 2017 luigiwalser <luigiwalser> 2.7.6-2.mga6
+ Revision: 1103784
- rebuild for core

* Sat Apr 22 2017 luigiwalser <luigiwalser> 2.7.6-1.mga6
+ Revision: 1097111
- 2.7.6

* Fri Apr 14 2017 luigiwalser <luigiwalser> 2.7.5-1.mga6
+ Revision: 1096524
- 2.7.5

* Fri Mar 31 2017 luigiwalser <luigiwalser> 2.7.4-1.mga6
+ Revision: 1095491
- 2.7.4
- 2.7.3
- remove upstream patch

* Wed Feb 15 2017 luigiwalser <luigiwalser> 2.7.2-1.mga6
+ Revision: 1086200
- 2.7.2
- add patch to fix csv output from fedora

* Tue Jan 17 2017 luigiwalser <luigiwalser> 2.7.1-1.mga6
+ Revision: 1082116
- 2.7.1

* Fri Dec 23 2016 luigiwalser <luigiwalser> 2.7-1.mga6
+ Revision: 1076652
- 2.7

* Sun Oct 16 2016 tv <tv> 2.6.7-3.mga6
+ Revision: 1061150
- BR systemd-devel for macro definition (mga#12027)

* Thu Oct 06 2016 daviddavid <daviddavid> 2.6.7-2.mga6
+ Revision: 1059170
- fix scriptlet failed and a dangling link (mga#19527)
  * move systemctl disable + stop service to %%preun section
  * systemctl stop doesn't work so use systemctl kill instead

* Wed Sep 14 2016 luigiwalser <luigiwalser> 2.6.7-1.mga6
+ Revision: 1052559
- 2.6.7

* Wed Aug 10 2016 luigiwalser <luigiwalser> 2.6.6-1.mga6
+ Revision: 1045261
- 2.6.6

* Fri May 06 2016 luigiwalser <luigiwalser> 2.5.2-1.mga6
+ Revision: 1009927
- 2.5.2
- split z/OS plugin from audispd-plugins into own subpackage

* Thu Mar 03 2016 shlomif <shlomif> 2.5-3.mga6
+ Revision: 985042
- Bump rel for rebuild
- Fix groups and tabs and macros-in-comments
- Build python3 based on Fedora (Thanks!).

* Mon Jan 25 2016 luigiwalser <luigiwalser> 2.5-1.mga6
+ Revision: 927123
- 2.5

* Thu Dec 31 2015 luigiwalser <luigiwalser> 2.4.5-1.mga6
+ Revision: 917359
- 2.4.5

* Sat Sep 12 2015 fwang <fwang> 2.4.4-3.mga6
+ Revision: 878841
- rebuild for new libprelude

* Fri Aug 21 2015 tmb <tmb> 2.4.4-2.mga6
+ Revision: 867532
- rebuild for new gcc

* Fri Aug 14 2015 shlomif <shlomif> 2.4.4-1.mga6
+ Revision: 864662
- New ver 2.4.4 (Also security fix for MGA#16584)

* Fri Jul 17 2015 shlomif <shlomif> 2.4.3-1.mga6
+ Revision: 854879
- New version 2.4.3

* Sat Feb 21 2015 ennael <ennael> 2.4.1-1.mga5
+ Revision: 816206
- 2.4.1

* Wed Oct 15 2014 umeabot <umeabot> 2.4-4.mga5
+ Revision: 739252
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.4-3.mga5
+ Revision: 725970
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.4-2.mga5
+ Revision: 678047
- Mageia 5 Mass Rebuild

* Sun Aug 31 2014 luigiwalser <luigiwalser> 2.4-1.mga5
+ Revision: 670098
- 2.4
- ghost audit rules file so the package will own it
- add pkgconfig file to files list

* Sat May 31 2014 pterjan <pterjan> 2.3.6-2.mga5
+ Revision: 628108
- Rebuild for new Python

* Mon Apr 28 2014 shlomif <shlomif> 2.3.6-1.mga5
+ Revision: 618558
- New version 2.3.6

* Thu Apr 03 2014 spuhler <spuhler> 2.3.5-1.mga5
+ Revision: 611443
- upgrade to ver. 2.3.5

* Wed Apr 02 2014 spuhler <spuhler> 2.3.4-6.mga5
+ Revision: 611342
+ rebuild (emptylog)

* Wed Apr 02 2014 spuhler <spuhler> 2.3.4-5.mga5
+ Revision: 611242
- removed the cp rules script

* Wed Apr 02 2014 spuhler <spuhler> 2.3.4-4.mga5
+ Revision: 611232
- added the system start auditd.service and stop command at post and preun lines
  * The macros don't work for this.

* Mon Mar 17 2014 spuhler <spuhler> 2.3.4-3.mga5
+ Revision: 604479
- added systemctl enable -q auditd.service
  * because the macro %%_post_service auditd doesn't work
  * service needs to be started before sysinit.target
- similar in the %%preun section, systemctl disable -q auditd.service

* Thu Mar 13 2014 spuhler <spuhler> 2.3.4-2.mga5
+ Revision: 602753
- added audit-tmpfiles.conf
 - added in %%post %%_tmpfilescreate %%{name}
 - added in %%files section %%{_tmpfilesdir}/%%{name}.conf

* Tue Mar 11 2014 spuhler <spuhler> 2.3.4-1.mga5
+ Revision: 602496
- upgrade to ver. 2.3.4

* Tue Mar 11 2014 colin <colin> 2.3.2-3.mga5
+ Revision: 602436
- Remove /-vs-/usr complexity now that usrmove is completed
- Switch to systemd units (sysvinit script was broken due to LSB patch removal mga#12977)

* Sat Oct 19 2013 umeabot <umeabot> 2.3.2-2.mga4
+ Revision: 532572
- Mageia 4 Mass Rebuild

* Wed Aug 21 2013 spuhler <spuhler> 2.3.2-1.mga4
+ Revision: 468634
- removed un-needed mkdir m4 line in spec
- upgrade to ver 2.3.2
- removed autdated patches

* Wed Jun 26 2013 wally <wally> 2.2.3-2.mga4
+ Revision: 447289
- drop old conflicts/obsoletes
- drop unneeded requires
- disable static build
- clean .spec a bit

* Sun Mar 31 2013 luigiwalser <luigiwalser> 2.2.3-1.mga3
+ Revision: 406904
- 2.2.3
- fix clone syscall interpretation (patch1 from fedora)

* Fri Jan 11 2013 umeabot <umeabot> 2.2.2-5.mga3
+ Revision: 346586
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 tmb <tmb> 2.2.2-4.mga3
+ Revision: 344010
- dont own _libdir/audit, it belongs to glibc

* Sat Jan 05 2013 spuhler <spuhler> 2.2.2-3.mga3
+ Revision: 339175
- bumped rel to get it rebuilt against new glibc

* Fri Jan 04 2013 spuhler <spuhler> 2.2.2-2.mga3
+ Revision: 338517
- bumped rel to make it rebuild
- did some cleaning on spec file

* Fri Jan 04 2013 spuhler <spuhler> 2.2.2-1.mga3
+ Revision: 338501
- upgrade to 2.2.2

* Mon Dec 31 2012 wally <wally> 2.2.1-2.mga3
+ Revision: 336503
- fix build with new automake 1.13

* Fri Sep 07 2012 spuhler <spuhler> 2.2.1-1.mga3
+ Revision: 289145
- upgrade to 2.2.1

* Thu Nov 24 2011 pterjan <pterjan> 2.1.3-1.mga2
+ Revision: 171751
- Update to 2.1.3

* Thu Sep 08 2011 tv <tv> 2.1.2-1.mga2
+ Revision: 141589
- fix LSB end tag
- new release

* Wed Apr 13 2011 tv <tv> 2.0.6-1.mga1
+ Revision: 84099
- new release

* Mon Jan 17 2011 pterjan <pterjan> 2.0.5-3.mga1
+ Revision: 21346
- Rebuild for python 2.7

* Sun Jan 09 2011 pterjan <pterjan> 2.0.5-2.mga1
+ Revision: 4524
- Drop obsolete requires
- Get the 2.0.5 update
- Get the 2.0.5 update
- Drop obsolete stuff
- imported package audit


* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 2.0.4-5mdv2010.1
+ Revision: 523828
- more split and deps fixes

* Tue Mar 16 2010 Oden Eriksson <oeriksson@mandriva.com> 2.0.4-4mdv2010.1
+ Revision: 521483
- fix deps

* Mon Mar 15 2010 Oden Eriksson <oeriksson@mandriva.com> 2.0.4-3mdv2010.1
+ Revision: 519924
- refine the split

* Mon Mar 15 2010 Oden Eriksson <oeriksson@mandriva.com> 2.0.4-2mdv2010.1
+ Revision: 519883
- fix build
- revert the lib split

* Sun Mar 14 2010 Oden Eriksson <oeriksson@mandriva.com> 2.0.4-1mdv2010.1
+ Revision: 519090
- 2.0.4 (sync with audit-2.0.4-3.fc13.src.rpm)
- rebuild
- bump release
- disable gssapi support (bogdano)

* Mon Jul 27 2009 Emmanuel Andry <eandry@mandriva.org> 1.7.13-1mdv2010.0
+ Revision: 400832
- New version 1.7.13
- drop p101 and p103 (merged upstream)
- check major

* Mon Apr 06 2009 Frederik Himpe <fhimpe@mandriva.org> 1.7.12-3mdv2009.1
+ Revision: 364560
- Add LSB headers to init script (bug #49587)
- Add Fedora patches:
  * Handle audit=0 boot option for 2.6.29 kernel (RH Bug 487541)
  * Drop some debug code in libev
  * Move audit.py file to arch specific python dir

* Thu Feb 26 2009 Oden Eriksson <oeriksson@mandriva.com> 1.7.12-1mdv2009.1
+ Revision: 345019
- 1.7.12
- sync with the bundled spec file

* Sun Jan 11 2009 Oden Eriksson <oeriksson@mandriva.com> 1.7.11-1mdv2009.1
+ Revision: 328322
- 1.7.11
- drop P2, it's fixed upstream

* Fri Dec 26 2008 Funda Wang <fwang@mandriva.org> 1.7.10-2mdv2009.1
+ Revision: 319212
- rebuild for new python

* Sat Dec 20 2008 Oden Eriksson <oeriksson@mandriva.com> 1.7.10-1mdv2009.1
+ Revision: 316500
- 1.7.10
- drop one redundant patch
- fix build with -Werror=format-security (P2)

* Thu Nov 06 2008 Oden Eriksson <oeriksson@mandriva.com> 1.7.9-1mdv2009.1
+ Revision: 300182
- 1.7.9

* Thu Oct 23 2008 Oden Eriksson <oeriksson@mandriva.com> 1.7.8-1mdv2009.1
+ Revision: 296652
- 1.7.8

* Thu Sep 18 2008 Oden Eriksson <oeriksson@mandriva.com> 1.7.7-1mdv2009.0
+ Revision: 285646
- 1.7.7 (Major bugfixes)
- drop upstream implemented patches

* Sat Sep 13 2008 Oden Eriksson <oeriksson@mandriva.com> 1.7.6-2mdv2009.0
+ Revision: 284587
- remove the _disable_ld_as_needed workaround, it's fixed in P5

* Sat Sep 13 2008 Oden Eriksson <oeriksson@mandriva.com> 1.7.6-1mdv2009.0
+ Revision: 284451
- use _disable_ld_as_needed because auditd won't link
  against -lwrap otherwise
- added one security fix from svn (P4)

* Fri Sep 12 2008 Oden Eriksson <oeriksson@mandriva.com> 1.7.6-0.1mdv2009.0
+ Revision: 284213
- 1.7.6, enables tcp_wrappers support but don't
  link it in for some reason...
- misc spec file fixes

* Tue Aug 26 2008 Oden Eriksson <oeriksson@mandriva.com> 1.7.5-1mdv2009.0
+ Revision: 276119
- 1.7.5

* Fri Aug 08 2008 Thierry Vignaud <tv@mandriva.org> 1.7.3-3mdv2009.0
+ Revision: 267862
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Mon May 19 2008 Oden Eriksson <oeriksson@mandriva.com> 1.7.3-1mdv2009.0
+ Revision: 209147
- 1.7.3
- drop upstream applied patches
- 1.7.2
- sync with fedora (audit-1.7.2-6.fc9.src.rpm)

* Sat Apr 12 2008 Oden Eriksson <oeriksson@mandriva.com> 1.6.8-1mdv2009.0
+ Revision: 192614
- P2: security fix for CVE-2008-1628

* Thu Feb 14 2008 Oden Eriksson <oeriksson@mandriva.com> 1.6.8-1mdv2008.1
+ Revision: 168666
- 1.6.8

* Fri Feb 01 2008 Oden Eriksson <oeriksson@mandriva.com> 1.6.7-1mdv2008.1
+ Revision: 161092
- 1.6.7
- dropped P2, it's implemented upstream
- added the prelude support (plugins should be broken out)

* Fri Jan 11 2008 Andreas Hasenack <andreas@mandriva.com> 1.6.5-2mdv2008.1
+ Revision: 148491
- rebuild to force re-upload

* Tue Jan 08 2008 Andreas Hasenack <andreas@mandriva.com> 1.6.5-1mdv2008.1
+ Revision: 146739
- updated to version 1.6.5

* Thu Jan 03 2008 Andreas Hasenack <andreas@mandriva.com> 2mdv2008.1-current
+ Revision: 142635
- fix log file permissions check

* Thu Jan 03 2008 Andreas Hasenack <andreas@mandriva.com> 1.6.4-1mdv2008.1
+ Revision: 142477
- updated to version 1.6.4
- imported Oden's changes:
  - new plugin package
  - am_cflags patch
  - spec cleanup
  - openldap-devel buildrequires

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Sep 25 2007 Andreas Hasenack <andreas@mandriva.com> 1.6.1-5mdv2008.0
+ Revision: 92698
- fixed "config file too large" on x86_64 (#33891)
- added some missing requires for system-config-audit

* Mon Sep 24 2007 Andreas Hasenack <andreas@mandriva.com> 1.6.1-4mdv2008.0
+ Revision: 92509
- change menu icon (#33920)
- fix sendmail check (#33891)

* Fri Sep 21 2007 Andreas Hasenack <andreas@mandriva.com> 1.6.1-3mdv2008.0
+ Revision: 92101
- fixed menu (#33868)
- fixed duplicated lang entry (#33874)

* Fri Sep 21 2007 David Walluck <walluck@mandriva.org> 1.6.1-2mdv2008.0
+ Revision: 92084
- add some devel provides for fc compat
- use %%{configure2_5x} and %%{makeinstall_std}

* Tue Sep 18 2007 Andreas Hasenack <andreas@mandriva.com> 1.6.1-1mdv2008.0
+ Revision: 89849
- updated to version 1.6.1
- obey new library policy (unversioned devel)
- properly package system-config-audit GUI

* Sun Sep 16 2007 Thierry Vignaud <tv@mandriva.org> 1.5.6-4mdv2008.0
+ Revision: 87792
- fix system-config-audit starting (#33354)

* Mon Aug 13 2007 Thierry Vignaud <tv@mandriva.org> 1.5.6-3mdv2008.0
+ Revision: 62632
- add missing requires for python module (#32503)

* Fri Aug 10 2007 Thierry Vignaud <tv@mandriva.org> 1.5.6-2mdv2008.0
+ Revision: 61460
- run %%find_lang in %%install
- package missing files
- create libaudit-common sub package
- add missing buildrequires
- new release
- fix build
- new devel policy

  + Andreas Hasenack <andreas@mandriva.com>
    - buildrequires glibc-devel which has the needed headers
    - updated to version 1.5.4
    - fixed group
    - fixed requires
    - fixer provides
    - Import audit

